@@ -1,6 +1,3 @@
-import logging
-import os
-
 import altair as alt
 import numpy as np
 import pandas as pd
@@ -9,38 +6,6 @@ from profiling.metrics import getloss
 from profiling.utils import df_to_json_table
 
 
-def create_accuracy(endpoint, basepath="results"):
-    """Create accuracy profile for endpoint"""
-    func = endpoint.func
-    X = endpoint.X
-    y = endpoint.y
-
-    kind = endpoint.kind
-    folder = os.path.join(basepath, func.__name__, "accuracy")
-    if not os.path.exists(folder):
-        os.makedirs(folder)
-
-    logging.info("Accuracy - Creating calibration plot")
-    fname = "calibration.json"
-    fpath = os.path.join(folder, fname)
-    chart = calibration(func, X, y)
-    chart.save(fpath, format="json")
-
-    logging.info("Accuracy - Creating metrics table")
-    fname = "metrics.json"
-    fpath = os.path.join(folder, fname)
-    metrics_table = metrics(func, X, y, kind)
-    with open(fpath, "w") as f:
-        f.write(metrics_table)
-
-    logging.info("Accuracy - Finding largest errors")
-    fname = "errors.json"
-    fpath = os.path.join(folder, fname)
-    errors_table = largest_errors(func, X, y)
-    with open(fpath, "w") as f:
-        f.write(errors_table)
-
-
 def metrics(func, X, y, kind, formatstr="{:,.2f}"):
     if kind == "regression":
         loss_list = ["Rmse", "Mae", "TrimmedRmse", "MeanPrediction", "MeanActual"]
