@@ -2,6 +2,7 @@ import json
 import logging
 import os
 
+import pandas
 from fastapi.encoders import jsonable_encoder
 
 from .accuracy import calibration, largest_errors, metrics
@@ -153,8 +154,8 @@ def create_summary(endpoint, basepath="results"):
     as_json = {
         "name": endpoint_name,
         "kind": endpoint.kind,
-        "inputs": list(endpoint.X.columns),
-        "output": endpoint.y.name,
+        "inputs": endpoint.input_names,
+        "output": endpoint.output_names,
     }
     with open(os.path.join(basepath, endpoint_name, "summary.json"), "w") as summary:
         json.dump(as_json, summary)
