@@ -1,6 +1,3 @@
-import logging
-import os
-
 import altair as alt
 import numpy as np
 import pandas as pd
@@ -13,26 +10,6 @@ from pandas.api.types import (
 )
 
 
-def create_dependence(endpoint, basepath="results"):
-    """Create partial dependence graphs for all variables"""
-    func = endpoint.func
-    X = endpoint.X
-    y = endpoint.y
-    folder = os.path.join(basepath, func.__name__, "anatomy", "partialdep")
-    if not os.path.exists(folder):
-        os.makedirs(folder)
-
-    for var in X.columns:
-        logging.info(f"Explanations - Creating partial dependence for {var}")
-        fname = var + ".json"
-        fpath = os.path.join(folder, fname)
-        try:
-            chart = partialdep(func, X, y, var)
-            chart.save(fpath, format="json")
-        except AttributeError:
-            logging.warning(f"Could not generate valid chart for {var}")
-
-
 def partialdep(func, X, y, var):
     """Plot partial dependence"""
     if is_bool_dtype(X[var]) or is_object_dtype(X[var]):
