@@ -1,7 +1,3 @@
-import json
-import logging
-import os
-
 import altair as alt
 import numpy as np
 import pandas as pd
@@ -9,35 +5,6 @@ import pandas as pd
 from profiling.metrics import getloss
 
 
-def create_importance(endpoint, basepath="results"):
-    """Create variable importance graphs"""
-    func = endpoint.func
-    X = endpoint.X
-    y = endpoint.y
-
-    logging.info("Explanations - Calculating variable importance")
-    if endpoint.kind == "regression":
-        chart, varlist = varimp(func, X, y, metric="Rmse")
-    elif endpoint.kind == "binary":
-        chart, varlist = varimp(func, X, y, metric="AUC")
-    else:
-        raise NotImplementedError("Unknown endpoint kind:" + endpoint.kind)
-
-    # Save to disk
-    folder = os.path.join(basepath, func.__name__, "anatomy")
-    if not os.path.exists(folder):
-        os.makedirs(folder)
-
-    fname = "varimp.json"
-    fpath = os.path.join(folder, fname)
-    chart.save(fpath, format="json")
-
-    fname = "varlist.json"
-    fpath = os.path.join(folder, fname)
-    with open(fpath, "w") as f:
-        json.dump(varlist, f)
-
-
 def varimp(func, X, y, metric="Rmse", n_max=10000):
 
     # Sample from large dataframes
